'use strict';

var crypto     = require('crypto');

module.exports = sleuth;

/**
* @fileOverview Middleware distributed tracing solution for Koa2. This
* middleware is inspired in daper and in spring cloud sleuth.
*
* @author Noel Rodriguez
* @author Mario Vinuesa
* @version 1.0.0
*
* @example
*var koa = require('koa');
*var sleuth = require('koa-devstack-sleuth');
*var app = new koa();
*app.use(sleuth());
*/
function sleuth(options) {
    return async function (ctx, next){
        if (ctx == null || ctx === 'undefined'){
            console.error('Koa Framework is mandatory');
            return;
        }
        var id = crypto.randomBytes(8).toString('hex');
        if (ctx.get('X-B3-TraceId')){
            ctx.set('X-B3-TraceId',ctx.get('X-B3-TraceId'));
            ctx.set('X-B3-SpanId',id);
        } else {
            ctx.set('X-B3-SpanId',id);
            ctx.set('X-B3-TraceId',id);
        }
        return next();
    };
}